#
# spec file for package snallygaster
#
# Copyright (c) 2025 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


Name:           snallygaster
Version:        0.0.13
Release:        1.0.2.1.sr20250402
Summary:        Tool to scan for hidden files on HTTP servers
License:        0BSD
Group:          Development/Languages/Python
URL:            https://github.com/hannob/snallygaster
Source:         https://files.pythonhosted.org/packages/source/s/snallygaster/snallygaster-%{version}.tar.gz
Source1:        https://github.com/hannob/snallygaster-testdata/archive/refs/heads/master.tar.gz#/testdata.tar.gz
BuildRequires:  python-rpm-macros
BuildRequires:  python3-setuptools
# SECTION test requirements
BuildRequires:  python3-pytest
BuildRequires:  python3-beautifulsoup4 >= 4.11
BuildRequires:  python3-dnspython
BuildRequires:  python3-urllib3
# /SECTION
BuildRequires:  fdupes
# otherwise: cannot import XMLParsedAsHTMLWarning
Requires:       python3-beautifulsoup4 >= 4.11
Requires:       python3-dnspython
Requires:       python3-urllib3
BuildArch:      noarch

%description
A tool that looks for files accessible on web servers that shouldn't be public
and can pose a security risk.

Typical examples include publicly accessible git repositories, backup files
potentially containing passwords or database dumps. In addition, it contains
a few checks for other security vulnerabilities.

%prep
%setup -q -n snallygaster-%{version}
%setup -T -D -a 1
# -n snallygaster-testdata-master
mkdir snallygaster-testdata-master/.git/
echo '[core]' > snallygaster-testdata-master/.git/config

%build
%python3_build

%install
%python3_install
fdupes %{buildroot}%{python_sitelib}

%check
# remove tests irrelevant for us
rm tests/test_codingstyle.py tests/test_docs.py
export TESTDATA_REPOSITORY=$(pwd)/snallygaster-testdata-master/
export RUN_ONLINETESTS=1
PYTHONPATH=${PYTHONPATH:+$PYTHONPATH:}%BUILDROOT%{python3_sitelib}/snallygaster/ PYTHONDONTWRITEBYTECODE=1 pytest -v tests/

%files
%doc README.md
%license LICENSE
%{_bindir}/snallygaster
%{python3_sitelib}/snallygaster-%{version}*-info

%changelog
* Tue Apr 15 2025 Sebastian Wagner <sebix@sebix.at>
- Update to 0.0.13:
  - License change to 0BSD.
  - Django staticfile.json test (info).
  - Various minor fixes, style improvements, etc.
* Fri Sep  6 2024 Sebastian Wagner <sebix@sebix.at>
- run tests with pytest, as setuptools lost its test command
* Wed Feb  2 2022 Sebastian Wagner <sebix@sebix.at>
- remove unnecessary build dependency pyupgrade. We don't execute this test.
- remove tests irrelevant for us
* Wed Feb  2 2022 Sebastian Wagner <sebix@sebix.at>
- update to version 0.0.12:
  - use more f-strings
  - let pyupgrade enforce f-strings and latest python
  - use more f-strings
  - catch all the different ways the HTML parser can fail
  - Remove nargs=1, simplifies code
  - raise version to 0.0.11
* Tue Dec 28 2021 Sebastian Wagner <sebix@sebix.at>
- update to version 0.0.11:
  - disable python 3.11 tests for now due to pylint/wrapt incompatibility
  - fix pylint warning use-implicit-booleaness-not-comparison
  - add detection of symfony debugging mode on 404 pages
  - support v3 php-cs-fixer format and rename test
  - enable onlinetests in GH actions
  - improve apache server info detection / avoid false positives by adding closing h1 tag
  - remove apache perl status, add documentation for apache-info check
  - update check for apache-info, check for perl-info still need improving
  add check for apache server info and perl-status
  - Readme: add openSUSE package
* Fri Jun 18 2021 Sebastian Wagner <sebix@sebix.at>
- Update to version 0.0.10:
  - New test for Wordpress duplicator installer files and directory listings.
  - Move from Travis CI to Github Actions.
  - Fix and silence new pylint warnings.
- remove obsolete fix-codestyle.patch
* Fri May 14 2021 Sebastian Wagner <sebix@sebix.at>
- remove the codestyle tests, we are not interested in them, they cause blocking build fails
* Tue Apr  6 2021 Sebastian Wagner <sebix@sebix.at>
- add fix-codestyle.patch from https://github.com/hannob/snallygaster/pull/58 to replace a deprecated function.
  the deprecated function caused pylint to fail which is part of the unittests.
- add testdata and run full tests.
* Wed Oct  7 2020 Sebastian Wagner <sebix@sebix.at>
- update to version 0.0.9:
  - Fix composer false positive
  - disable broken python nightly, enable 3.9-dev
  - add http header injection test
  - doc for headerinject
  - check if we document all the tests in TESTS.md
  - fix pyflakes and pyupgrade warnings
  - add wordpress debug.log test
  - document wpdebug
  - add .orig to backupfiles test, created by patch tool
  - dnspython 2.x support, this requires using dns.resolver.resolve if av…
  - codingstyle for backupfiles
- update to version 0.0.8:
  - Test: phpinfo
  - code styling
  - add vb_test.php check
  - fix whitespace error from merge
  - document phpinfo
  - use annotated tags for changelog
* Sat Jul  4 2020 Sebastian Wagner <sebix@sebix.at>
- initial package for version 0.0.7
